"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var partido = require("./partido");
var coligacao = require("./coligacao");
var candidato_1 = require("./candidato");
var csvString;
if ((process.title !== 'browser')) {
    var csvFile = fs.readFileSync(process.argv[2]);
    csvString = csvFile.toString();
    var result = processaEleicao(csvString);
    console.log(result);
}
else {
    document.addEventListener("DOMContentLoaded", function (event) {
        var input = document.getElementById("csv-file");
        if (input) {
            input.addEventListener('change', addFileEvent);
        }
    });
}
function addFileEvent(event) {
    var target = event.target;
    if (target.files.length > 0) {
        readFileToString(target.files[0]).then(function (data) {
            var result = processaEleicao(data);
            var resultTag = document.getElementById("results");
            resultTag.innerText = result;
        });
    }
}
function readFileToString(file) {
    return new Promise(function (resolve, reject) {
        var reader = new FileReader();
        reader.readAsBinaryString(file);
        reader.onload = function () { return resolve(reader.result); };
        reader.onerror = function (error) { return reject(error); };
    });
}
function processaEleicao(csvString) {
    var nVagas = 0;
    var nVotosTotais = 0;
    var partidos = [];
    var coligacoes = [];
    var lines = csvString.split('\n');
    for (var line = 1; line < lines.length; line++) {
        if (lines[line][0] === undefined) {
            break;
        }
        var candidatoLine = lines[line].split(';');
        var partidoColigacao = candidatoLine[3].split('-');
        var partidoNome = partidoColigacao[0].trimRight();
        var coligacaoNome = partidoColigacao[1] !== undefined ? partidoColigacao[1].trimLeft() : partidoNome;
        var part = partido.findPartido(partidoNome, partidos);
        if (part === undefined) {
            part = new partido.Partido(partidoNome);
            partidos.push(part);
        }
        var colig = coligacao.findColigacao(coligacaoNome, coligacoes);
        if (colig === undefined) {
            colig = new coligacao.Coligacao(coligacaoNome);
            coligacoes.push(colig);
        }
        var nVotos = parseInt(candidatoLine[4].replace(/[^0-9]/, ''));
        var eleito = candidatoLine[0][0] === '*';
        nVotosTotais += nVotos;
        if (eleito)
            nVagas += 1;
        var candidato = new candidato_1.Candidato(candidatoLine[2], parseInt(candidatoLine[1]), part, colig, nVotos, eleito);
        part.addCandidato(candidato);
        colig.addCandidato(candidato);
    }
    partidos.sort(function (a, b) { return b.nVotos - a.nVotos; });
    coligacoes.sort(function (a, b) { return b.nVotos - a.nVotos; });
    var result = '';
    result = "N\u00FAmero Total de Vagas: " + nVagas;
    result += "\n\nVotação (nominal) das coligações e número de candidatos eleitos:";
    for (var i = 0; i < coligacoes.length; i++) {
        result += "\n" + (i + 1) + " - Coligacao: " + coligacoes[i];
    }
    result += "\n\nVotação (nominal) dos partidos e número de candidatos eleitos:";
    for (var i = 0; i < partidos.length; i++) {
        result += "\n" + (i + 1) + " - " + partidos[i];
    }
    result += "\n\nTotal de votos nominais: " + nVotosTotais;
    return result;
}
//# sourceMappingURL=main.js.map