import * as fs from "fs";
import * as partido from "./partido";
import * as coligacao from "./coligacao";
import {Candidato} from "./candidato";

let csvString: string
if(( process.title !== 'browser')){
    let csvFile = fs.readFileSync(process.argv[2]);
    csvString = csvFile.toString();
    const result = processaEleicao(csvString);
    console.log(result)
}else{
    document.addEventListener("DOMContentLoaded", function(event) {
        let input = document.getElementById("csv-file");
        if(input){
            input.addEventListener('change',addFileEvent)
        }
    });

}

function addFileEvent(event:Event) {
    let target = (<HTMLInputElement>event.target)
    if (target.files!.length > 0) {
        readFileToString(target.files![0]).then(
            (data:string) => {
                const result = processaEleicao(data)
                const resultTag =document.getElementById("results");
                resultTag!.innerText = result;
            }
        )
    }
}

function readFileToString(file: File){
 return new Promise<string>((resolve, reject) => {
     const reader = new FileReader();
     reader.readAsBinaryString(file);
     reader.onload = () => resolve(<string>reader.result);
     reader.onerror = error => reject(error);
 })
}

function processaEleicao(csvString:string){

    let nVagas:number = 0;
    let nVotosTotais:number = 0;
    let partidos: Array<partido.Partido> = [];
    let coligacoes: Array<coligacao.Coligacao> = [];

    const lines = csvString.split('\n');

    for(let line = 1; line < lines.length; line++){
        if(lines[line][0] === undefined){
            break;
        }
        const candidatoLine = lines[line].split(';');
        const partidoColigacao = candidatoLine[3].split('-');

        const partidoNome = partidoColigacao[0].trimRight();
        const coligacaoNome = partidoColigacao[1] !== undefined ? partidoColigacao[1].trimLeft() : partidoNome;

        let part = partido.findPartido(partidoNome,partidos);
        if(part === undefined){
            part = new partido.Partido(partidoNome)
            partidos.push(part)
        }

        let colig = coligacao.findColigacao(coligacaoNome,coligacoes);
        if(colig === undefined){
            colig = new coligacao.Coligacao(coligacaoNome)
            coligacoes.push(colig)
        }

        const nVotos =  parseInt(candidatoLine[4].replace(/[^0-9]/, ''));
        const eleito = candidatoLine[0][0] === '*'

        nVotosTotais += nVotos

        if(eleito)
            nVagas += 1;

        const candidato = new Candidato(
            candidatoLine[2],
            parseInt(candidatoLine[1]),
            part,
            colig,
            nVotos,
            eleito
        )

        part.addCandidato(candidato)
        colig.addCandidato(candidato)
    }

    partidos.sort((a,b) => b.nVotos - a.nVotos)
    coligacoes.sort((a,b) => b.nVotos - a.nVotos)

    let result = '';

    result = `Número Total de Vagas: ${nVagas}`

    result +="\n\nVotação (nominal) das coligações e número de candidatos eleitos:"
    for(let i = 0; i < coligacoes.length; i++){
        result += `\n${i+1} - Coligacao: ${coligacoes[i]}`
    }

    result += "\n\nVotação (nominal) dos partidos e número de candidatos eleitos:"
    for(let i = 0; i < partidos.length; i++){
        result +=`\n${i+1} - ${partidos[i]}`
    }
    result +=`\n\nTotal de votos nominais: ${nVotosTotais}`
    return result
}
